## Section 3.1
library("PoweR")
set.seed(1)
# help(package = "PoweR")

## Section 3.2
head(getindex()$mat.laws)
# help.law(6)
gensample(law.index = 2, n = 10, law.pars = c(1, 2))

## Section 3.3
head(getindex()$mat.stats)
getindex(stat.indices = c(17, 23, 78))
set.seed(1)
x <- rnorm(10)
shapiro.test(x)
statcompute(stat.index = 21, data = x, level = 0.05)
crit <- compquant(n = 10, law.index = 2, stat.index = 21, M = 10^5)
crit$quant

## Section 3.4
x <- rnorm(100)
statcompute(1, x, levels = 0.05, alter = 3)$pvalue
pvalueMC(x, stat.index = 1, null.law.index = 2, M = 10^5, alter = 3)

## Section 3.5
system.time({
  # Here we consider n = 1000 as being Infinity.
  law.index <- 1  # Laplace distribution.
  M <- 10^5  # Number of Monte-Carlo repetitions.
  vectn <- c(10, 15, 20, 35, 50, 75, 100, 1000)  # Sample sizes.
  levels <- c(0.50, 0.25, 0.10, 0.05, 0.025, 0.01)  # Significance levels. 
  table1 <- many.crit(law.index, stat.indices = 43, M, vectn, levels, alter = list(stat43 = 3))
})
print(table1, digits = 3)
print(table1, digits = 3, latex.output = TRUE)
system.time({
  law.index <- 1  # Laplace distribution.
  M <- 10^5
  vectn <- c(10, 15, 20, 35, 50, 75, 100)
  levels <- 0.05
  stat.indices <- c(43, 44, 42, 45, 46)
  law.indices <- c(2, 3, 4, 28)  # Normal, Cauchy, Logistic, GEV.
  alter <- create.alter(stat.indices, rep(3, 5))  # Type of each test.
  critval <- many.crit(law.index, stat.indices, M, vectn, levels, alter)
  table6 <- powcomp.fast(law.indices, stat.indices, vectn, M, levels, critval = critval, 
    alter)
})
print(table6, digits = 3, latex.output = TRUE)
stind <- c(43, 44, 42)  # Indices of test statistics.
alter <- create.alter(stind, rep(3, 3))  # Type for each test.
system.time({
  # Several p-values computed under the null.
  ptmpnull <- many.pval(stat.indices = stind, law.index = 1, n = 100, M = 10^5, 
    N = 10^5, alter = alter, null.dist = 2, method = "direct")$pvals
})
Fxnull <- calcFx(ptmpnull)
plot.pvalue(Fxnull)
plot.discrepancy(Fxnull, legend.pos = "topleft")
system.time({
  ptmpnull <- many.pval(stat.indices = stind, law.index = 1, n = 100, M = 10^5, 
    N = 10^5, alter = alter, null.dist = 2, method = "MC")$pvals
})
Fxnull <- calcFx(ptmpnull)
system.time({
  ptmp <- many.pval(stat.indices = stind, law.index = 4, n = 100, M = 10^5, N = 10^5, 
    alter = alter, null.dist = 2, method = "MC")$pvals
})
Fx <- calcFx(ptmp)
plot.sizepower(Fx, Fxnull)

## Section 3.6
## see puig.R

## Section 3.7
my.shapiro <- function(data, levels, usecrit = 0, critvalL = 0, critvalR = 0) {
  res <- shapiro.test(data)
  decisions <- rep(0, length(levels))
  for (i in 1:length(levels)) {
    if (usecrit == 0) {
      decisions[i] <- if (res$p.value < levels[i]) 
        1 else 0
    } else {
      decisions[i] <- if (res$statistic < critvalL[i]) 
        1 else 0
    }
  }
  return(list(statistic = res$statistic, pvalue = res$p.value, decision = decisions, 
    alter = 4, stat.pars = NULL, pvalcomp = 1L, nbparstat = 0))
}
M <- 10^5
levels <- 0.05
vectn <- c(10, 15, 100)
stind <- c(21, 0)
alter <- create.alter(stind, rep(4, 2))
(critval <- many.crit(law.index = 0, stat.indices = stind, M, vectn, levels, alter, 
  Rlaw = list(rnorm), law.pars = c(0, 1), Rstats = list(NULL, my.shapiro)))
library("VGAM")
law.indices <- c(2, 0)
(powcomp.fast(law.indices, stind, vectn, M, levels, critval = critval, alter, Rlaws = list(NULL, 
  rbenini), parlaws = list(law2 = c(0, 1), law0 = c(1, exp(1))), Rstats = list(NULL, 
  my.shapiro)))


## Section 3.8
# power.gui()


## Section 4.1
# Random sample from a Weibull(10,1) distribution:
x <- gensample(law.index = 11, n = 10^5, c(10, 1))$sample
mean(x)
var(x)
moments11(10, 1)
checklaw(law.index = 11, sample.size = 10^5, law.pars = c(10, 1), density = dlaw11)
# Identical to:
# checklaw(law.index = 11, sample.size = 10^5, law.pars = c(10, 1), density = dweibull)


## Section 4.2
x <- rnorm(100)
pvalueMC(x, stat.index = 21, null.law.index = 2, M = 10^5, alter = 4)
shapiro.test(x)$p.value 
